@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* APPL_DEBUG.ML: application interface *)
 (* Author: Mark Hayden, 11/97 *)
 (**************************************************************)
@@ -99,8 +90,3 @@ let view debug intf =
 
 (**************************************************************)
 
-let _ =
-  Elink.put Elink.appl_debug_f f ;
-  Elink.put Elink.appl_debug_view view
-
-(**************************************************************)
