@@ -251,7 +251,7 @@ let multiread    = bool set_ident false "multiread" "read all data from sockets
 let ranking      = string set_ranking Addr.default_ranking "ranking" "ranking of communication modes"
 let sched_step   = int set_pos_int 200 "sched_step" "number of events to schedule before reading from network"
 let udp_host     = string set_option None "udp_host" "override host for UDP communication"
-let udp_port     = int set_option None "udp_port" "override port for UDP communication"
+let udp_port     = int set_option (Some 0) "udp_port" "override port for UDP communication"
 let traces       = string set_ident "" "traces" "set modules to trace"
 let netsim_socks = bool set_ident false "netsim_socks" "allow socks with Netsim"
 let debug_real   = bool set_ident false "debug_real" "use real time for debugging logs"
