@@ -19,7 +19,7 @@ ce_malloc(int size)
     
     ptr = malloc(size);
     if (ptr == NULL) {
-	printf("Out of memory, exiting\n");
+	printf("Out of memory, exiting, tried to allocated <%d> bytes\n", size);
 	exit(1);
     }
     return ptr;
@@ -38,99 +38,30 @@ ce_realloc(void *ptr, int size)
     return ptr2;
 }
 
-#define ce_free(x) if (x != NULL) free(x)
-
-LINKDLL char*
-ce_copy_string(char *str){
-    char *buf;
-    int len;
-    
-    TRACE("ce_copy_string(");
-    len = strlen(str);
-    buf = malloc(len+1);
-    TRACE(".");
-    memcpy(buf,str,len);
-    buf[len] = '\0';
-    TRACE(")");
-    return buf;
-}
-
-void
-ce_view_id_free(ce_view_id_t *id){
-    ce_free(id->endpt);
-    ce_free(id);
-}
-
-/* Ce_Free a null terminated string array.
- */
-void
-ce_string_array_free(char **sa){
-    int i=0;
-    
-    while (sa[i] != NULL) {
-	ce_free(sa[i]);
-	i++;
-    }
-    ce_free(sa);
-}
-
-/* Free a null terminated view_id array.
- */
-void
-ce_view_id_array_free(ce_view_id_array_t va){
-    int i=0;
-    
-    while (va[i] != NULL) {
-	ce_view_id_free(va[i]);
-	i++;
-    }
-    ce_free(va);
-}
-
-
-LINKDLL void ce_view_full_free(ce_local_state_t *ls, ce_view_state_t* vs) {
+void ce_view_full_free(ce_local_state_t *ls, ce_view_state_t* vs)
+{
     if ((ls == NULL) && (vs == NULL))
 	return;
     
     TRACE("ce_view_full_free(");
-    ce_free(vs->version);    ce_free(vs->group);
-    ce_free(vs->proto);
-    ce_free(vs->key);
-    ce_view_id_array_free(vs->prev_ids);
-    ce_free(vs->params);
-    ce_string_array_free(vs->view);
-    ce_string_array_free(vs->address);
+    ce_free(vs->prev_ids);
+    ce_free(vs->view);
+    ce_free(vs->address);
     ce_free(vs);
     TRACE(".");
-    
-    ce_free(ls->endpt);
-    ce_free(ls->addr);
-    ce_free(ls->name);
-    ce_view_id_free(ls->view_id);
     ce_free(ls);
     TRACE(")");
 }
 
-LINKDLL void ce_jops_free(ce_jops_t* jops) {
-    TRACE("ce_jops_free(");
-    ce_free(jops->transports);
-    TRACE(".");
-    ce_free(jops->protocol);
-    TRACE(".");
-    ce_free(jops->group_name);
-    TRACE(".");
-    ce_free(jops->properties);
-    TRACE(".");
-    ce_free(jops->params);
-    TRACE(".");
-    ce_free(jops->endpt);
-    TRACE(".");
-    ce_free(jops->princ);
-    TRACE(".");
-    ce_free(jops->key);
-    TRACE(".");
+
+void ce_jops_copy(ce_jops_t *src, ce_jops_t *trg)
+{
+    memcpy(trg, src, sizeof(ce_jops_t));
+}
+
+void ce_jops_free(ce_jops_t *jops)
+{
     ce_free(jops);
-    TRACE(")");
 }
 
 
@@ -147,17 +78,20 @@ ce_st_create_intf(ce_env_t env,
 	       ce_appl_receive_cast_t receive_cast,
 	       ce_appl_receive_send_t receive_send,
 	       ce_appl_heartbeat_t heartbeat
-    ){
-    ce_appl_intf_t* intf = record_create(ce_appl_intf_t*, intf) ;
+    )
+{
+    ce_appl_intf_t* intf = (ce_appl_intf_t*) ce_malloc(sizeof(ce_appl_intf_t));
 
+    memset(intf, 0, sizeof(ce_appl_intf_t));
     intf->env = env;
     intf->id = id_counter++;
 
+	intf->magic = CE_MAGIC;
     intf->joining = 0;
     intf->leaving = 0;
     intf->blocked = 0;
     
-    intf->aq = ce_create_queue ();
+    intf->aq = ce_queue_create ();
     intf->req_heartbeat = 0;
     intf->exit = exit ;
     intf->install = install ;
@@ -172,14 +106,17 @@ ce_st_create_intf(ce_env_t env,
 
 
 void
-ce_intf_free(ce_appl_intf_t* intf){
-    ce_queue_clear(intf->aq);
-    ce_queue_free(intf->aq);
+ce_intf_free(ce_pool_t *pool, ce_appl_intf_t* intf)
+{
+    if (pool != NULL)
+	ce_queue_free(pool, intf->aq);
+	memset(intf, 0, sizeof(ce_appl_intf_t));
     ce_free(intf);
 }
 
 char**
-ce_process_args(int argc, char **argv){
+ce_process_args(int argc, char **argv)
+{
     int i,j ;
     int ml_args=0;
     char **ret = NULL;
