@@ -1,12 +1,8 @@
-//**************************************************************
-//*
-//*  Ensemble, (Version 0.70p1)
-//*  Copyright 2000 Cornell University
-//*  All rights reserved.
-//*
-//*  See ensemble/doc/license.txt for further information.
-//*
-//**************************************************************
+/**************************************************************/
+/* Hot_JoinOps.java */
+/* Author: Jason Dale */
+/**************************************************************/
+
 package ensemble.hot;
 
 public class Hot_JoinOps {
@@ -23,6 +19,10 @@ public class Hot_JoinOps {
     public String[] argv;
     public boolean debug;
     public boolean client;
+    public String princ;
+    public String key;
+    public boolean secure;
+
     public String outboard;
 
     public Hot_JoinOps() {
@@ -37,6 +37,9 @@ public class Hot_JoinOps {
 	argv = null;
 	env = null;
 	client = false;
+	princ = "";
+	key = "";
+	secure = false;
     }
 
 // End class Hot_JoinOps
