@@ -1,13 +1,4 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* MUTIL.ML *)
 (* Author: Mark Hayden, 8/97 *)
 (* Designed with Roy Friedman *)
@@ -44,18 +35,6 @@ type coord_msg =
 
 (**************************************************************)
 
-let string_of_member_msg = function
-  | Join(ltime) -> sprintf "Join(%d)" ltime
-  | Synced -> "Synced"
-  | Fail(endpts) -> sprintf "Fail(%d)" (List.length endpts)
-
-let string_of_coord_msg = function
-  | View(ltime,primary,view) -> sprintf "View(%d,%b,%d)" ltime primary (List.length view)
-  | Failed(_) -> "Failed"
-  | Sync -> "Sync"
-
-(**************************************************************)
-
 let soer = ref (fun _ -> raise Not_found)
 let set_string_of_endpt soe = soer := soe
 
@@ -67,6 +46,19 @@ let string_of_endpt endpt =
 
 (**************************************************************)
 
+let string_of_member_msg = function
+  | Join(ltime) -> sprintf "Join(%d)" ltime
+  | Synced -> "Synced"
+  | Fail(endpts) -> sprintf "Fail(%s)" (string_of_list string_of_endpt endpts)
+
+let string_of_coord_msg = function
+  | View(ltime,primary,view) -> sprintf "View(%d,%b,%d)" ltime primary (List.length view)
+  | Failed(_) -> "Failed"
+  | Sync -> "Sync"
+
+
+(**************************************************************)
+
 type state =
   | GNormal
   | GSynced
