@@ -1,16 +1,8 @@
 (**************************************************************)
-(*
- *  Ensemble, 1.10
- *  Copyright 2001 Cornell University, Hebrew University
- *  All rights reserved.
- *
- *  See ensemble/doc/license.txt for further information.
- *)
-(**************************************************************)
-(**************************************************************)
 (* HOT_UTIL.MLI *)
 (* Authors: Alexey Vaysburd, Mark Hayden 11/96 *)
 (**************************************************************)
+open Ensemble
 open Trans
 open Buf
 (**************************************************************)
