@@ -1,6 +1,6 @@
 open Str
 open Unix
-open Aux
+open Auxl
 open Coord
 open Printf
 
